fetch_awin: fetch_awin A function to fetch Awin data from the windsor.ai...

View source: R/fetch_awin.R

fetch_awinR Documentation

fetch_awin A function to fetch Awin data from the windsor.ai API

Description

fetch_awin A function to fetch Awin data from the windsor.ai API

Usage

fetch_awin(
  api_key,
  date_from = NULL,
  date_to = NULL,
  fields = c("campaign", "clicks", "spend", "impressions", "date")
)

Arguments

api_key

Your api key to access Windsor.ai API

date_from

The date from which to start getting data in format YYYY-MM-DD

date_to

The date until which to start getting data in format YYYY-MM-DD

fields

he fields fetched from the API for a given connector See https://windsor.ai/api-fields/ for details.

Value

A data frame with the desired data

Examples

## Not run: 
my_awin_data <- fetch_awin(api_key = "your api key",
date_from = "2022-10-01",
date_to = "2022-10-02",
fields = c("campaign", "clicks",
"spend", "impressions", "date"))

## End(Not run)

awinR documentation built on Nov. 30, 2022, 5:09 p.m.