my_awin_data: Sample of digital marketing data from Awin downloaded by...

my_awin_dataR Documentation

Sample of digital marketing data from Awin downloaded by means of the Windsor.ai API.

Description

A dataset containing sample Awin data fetched from windsor.ai API. See more at: https://windsor.ai/

Usage

my_awin_data

Format

A data frame with 164 rows and 5 variables:

campaign

name of the campaign

clicks

number of clicks

spend

spend data

impressions

impressions data

date

date

https://windsor.ai/


awinR documentation built on Nov. 30, 2022, 5:09 p.m.